@@ -1,5 +1,5 @@
 require "numru/gave/draw"
-require "vtk/Gtk"
+require "vtk/gtk"
 
 GAVE_GTK_VERSION = 2
 
